==============
Citing Crappy
==============

If Crappy has been of help in your research, please reference it in your 
academic publications by citing the following article :

- Couty V., Witz J-F., Martel C. et al., *Command and Real-Time Acquisition in Parallelized Python, a Python module for experimental setups*, SoftwareX 16, 2021, DOI: 10.1016/j.softx.2021.100848. (`publisher link <https://www.sciencedirect.com/science/article/pii/S2352711021001278>`_)

Here is the BibTex code for citing the article :

.. code-block:: shell-session

    @article{COUTY2021100848,
             title = {CRAPPY: Command and Real-Time Acquisition in Parallelized Python, a Python module for experimental setups},
             journal = {SoftwareX},
             volume = {16},
             pages = {100848},
             year = {2021},
             issn = {2352-7110},
             doi = {https://doi.org/10.1016/j.softx.2021.100848},
             url = {https://www.sciencedirect.com/science/article/pii/S2352711021001278},
             author = {Victor Couty and Jean-François Witz and Corentin Martel and François Bari and Antoine Weisrock},
             keywords = {Control-command, Acquisition, Python, Experimental setup},
             }
